@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/output.c,v 1.3 1998/04/27 07:01:33 newt Exp newt $";
-#endif
 /*****
 * output.c : XmHTML Text output routines.
 *
@@ -196,12 +193,12 @@ _XmHTMLTextGetPlain(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 	XmHTMLObjectTableElement start, XmHTMLObjectTableElement end,
 	Byte options)
 {
-	int x_pos, y_pos, maxlen, width;
+	int x_pos, maxlen, width;
 	XmHTMLObjectTable *elePtr;
 	XmHTMLWord *words;
 	String text = NULL, chPtr;
 	int nchars = 0, n_words;
-	int i, j, k, l, nused = 0;
+	int i, k, l, nused = 0;
 
 	if(pdef->unit_type != XmHTML_CHAR)
 	{
@@ -212,7 +209,6 @@ _XmHTMLTextGetPlain(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 
 	/* default start points */
 	x_pos = pdef->left_margin;
-	y_pos = pdef->top_margin;
 	maxlen = pdef->width - pdef->left_margin;
 	width = x_pos;
 
@@ -336,7 +332,6 @@ _XmHTMLTextGetPlain(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 		return(NULL);
 
 	/* okay, got it. Now fill the searchable table */
-	j = 0;
 	chPtr = text;
 	width = x_pos;
 	nused = 0;
@@ -625,12 +620,12 @@ _XmHTMLTextGetPS(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 	HTML_ATTR(work_width) = pdef->width - pdef->right_margin;
 
 	/* we also will be needing seperate GC's for this */
-	HTML_ATTR(gc) = tka->CreateGC(tka->dpy, pixmap, 0, NULL);
+	HTML_ATTR(gc) = tka->CreateGC(tka, pixmap, 0, NULL);
 	tka->SetFunction(tka->dpy, HTML_ATTR(gc), tka->gc_func[GC_GXcopy]);
 	tka->SetForeground(tka->dpy, HTML_ATTR(gc), HTML_ATTR(body_fg));
 	tka->SetBackground(tka->dpy, HTML_ATTR(gc), HTML_ATTR(body_bg));
 
-	HTML_ATTR(bg_gc) = tka->CreateGC(tka->dpy, pixmap, 0, NULL);
+	HTML_ATTR(bg_gc) = tka->CreateGC(tka, pixmap, 0, NULL);
 	tka->CopyGC(tka->dpy, HTML_ATTR(gc), 0xFFFF, HTML_ATTR(bg_gc));
 
 	/* set new drawable */
@@ -804,12 +799,12 @@ _XmHTMLTextGetPS(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 	HTML_ATTR(work_width) = pdef->width - pdef->right_margin;
 
 	/* we also will be needing seperate GC's for this */
-	HTML_ATTR(gc) = tka->CreateGC(tka->dpy, pixmap, 0, NULL);
+	HTML_ATTR(gc) = tka->CreateGC(tka, pixmap, 0, NULL);
 	tka->SetFunction(tka->dpy, HTML_ATTR(gc), tka->gc_func[GC_GXcopy]);
 	tka->SetForeground(tka->dpy, HTML_ATTR(gc), HTML_ATTR(body_fg));
 	tka->SetBackground(tka->dpy, HTML_ATTR(gc), HTML_ATTR(body_bg));
 
-	HTML_ATTR(bg_gc) = tka->CreateGC(tka->dpy, pixmap, 0, NULL);
+	HTML_ATTR(bg_gc) = tka->CreateGC(tka, pixmap, 0, NULL);
 	tka->CopyGC(tka->dpy, HTML_ATTR(gc), 0xFFFF, HTML_ATTR(bg_gc));
 
 	/* set new drawable */
