@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/colors.c,v 1.15 1998/04/27 06:58:36 newt Exp newt $";
-#endif
 /*****
 * colors.c : XmHTML color allocation routines
 *
@@ -92,6 +89,12 @@ static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/colors.c,v 1.15 199
 #include <string.h>
 #include <ctype.h>
 
+#include <png.h> /* must be included before Xft because it would create build problems if it were included afterwards. ( it is indirectly included by plc.h ) */
+#ifdef HAVE_XFT
+#include <X11/Xft/Xft.h>
+#endif
+#include <X11/Xlib.h>
+
 #include "toolkit.h"
 #include XmHTMLPrivateHeader
 
@@ -330,8 +333,12 @@ _XmHTMLConfirmColor32(char *color)
 			if(!strcasecmp(color, html_32_color_names[i]))
 			{
 				color = realloc(color, strlen(html_32_color_values[i]));
-				strcpy(color, html_32_color_values[i]);
-				color[strlen(html_32_color_values[i])] = '\0';
+				if (color)
+				 {
+				  strcpy(color, html_32_color_values[i]);
+				  color[strlen(html_32_color_values[i])] = '\0';
+				  free(color);
+				 }
 				return(True);
 			}
 		}
