@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/output.c,v 1.3 1998/04/27 07:01:33 newt Exp newt $";
-#endif
 /*****
 * output.c : XmHTML Text output routines.
 *
@@ -471,12 +468,12 @@ _XmHTMLTextGetPS(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 	HTML_ATTR(work_width) = pdef->width - pdef->right_margin;
 
 	/* we also will be needing seperate GC's for this */
-	HTML_ATTR(gc) = tka->CreateGC(tka->dpy, pixmap, 0, NULL);
+	HTML_ATTR(gc) = tka->CreateGC(tka, pixmap, 0, NULL);
 	tka->SetFunction(tka->dpy, HTML_ATTR(gc), tka->gc_func[GC_GXcopy]);
 	tka->SetForeground(tka->dpy, HTML_ATTR(gc), HTML_ATTR(body_fg));
 	tka->SetBackground(tka->dpy, HTML_ATTR(gc), HTML_ATTR(body_bg));
 
-	HTML_ATTR(bg_gc) = tka->CreateGC(tka->dpy, pixmap, 0, NULL);
+	HTML_ATTR(bg_gc) = tka->CreateGC(tka, pixmap, 0, NULL);
 	tka->CopyGC(tka->dpy, HTML_ATTR(gc), 0xFFFF, HTML_ATTR(bg_gc));
 
 	/* set new drawable */
@@ -650,12 +647,12 @@ _XmHTMLTextGetPS(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 	HTML_ATTR(work_width) = pdef->width - pdef->right_margin;
 
 	/* we also will be needing seperate GC's for this */
-	HTML_ATTR(gc) = tka->CreateGC(tka->dpy, pixmap, 0, NULL);
+	HTML_ATTR(gc) = tka->CreateGC(tka, pixmap, 0, NULL);
 	tka->SetFunction(tka->dpy, HTML_ATTR(gc), tka->gc_func[GC_GXcopy]);
 	tka->SetForeground(tka->dpy, HTML_ATTR(gc), HTML_ATTR(body_fg));
 	tka->SetBackground(tka->dpy, HTML_ATTR(gc), HTML_ATTR(body_bg));
 
-	HTML_ATTR(bg_gc) = tka->CreateGC(tka->dpy, pixmap, 0, NULL);
+	HTML_ATTR(bg_gc) = tka->CreateGC(tka, pixmap, 0, NULL);
 	tka->CopyGC(tka->dpy, HTML_ATTR(gc), 0xFFFF, HTML_ATTR(bg_gc));
 
 	/* set new drawable */
